@@ -455,13 +455,14 @@ mod tests {
 
     type MmapRegion = super::MmapRegion<()>;
 
-    // Adding a helper method to extract the errno within an Error::Mmap(e), or return a
-    // distinctive value when the error is represented by another variant.
     impl Error {
+        /// Helper method to extract the errno within an
+        /// `Error::Mmap(e)`. Returns `i32::MIN` if `self` is any
+        /// other variant.
         pub fn raw_os_error(&self) -> i32 {
             match self {
                 Error::Mmap(e) => e.raw_os_error().unwrap(),
-                _ => std::i32::MIN,
+                _ => i32::MIN,
             }
         }
     }
@@ -552,7 +553,7 @@ mod tests {
 
         // Offset + size will overflow.
         let r = MmapRegion::build(
-            Some(FileOffset::from_arc(a.clone(), std::u64::MAX)),
+            Some(FileOffset::from_arc(a.clone(), u64::MAX)),
             size,
             prot,
             flags,
